package com.gxlu.ps.netcruise.md.sender;

import com.gxlu.ps.netcruise.md.Configer;
import com.gxlu.ps.netcruise.md.GlobalInstance;
import com.gxlu.ps.netcruise.md.buffer.AlarmPool;
import com.gxlu.ps.netcruise.md.util.Alarm;
import java.io.IOException;
import java.io.OutputStream;
import java.net.Socket;
import java.util.LinkedList;
import org.apache.log4j.Logger;

/* loaded from: com_gxlu_ps_netcruise_md_sender.jar:com/gxlu/ps/netcruise/md/sender/AlarmSender.class */
public class AlarmSender extends Thread {
    protected static final int DISCONNECT = 0;
    protected static final int CONNECTED = 1;
    protected Socket socket;
    protected int maxInterval;
    protected String NCAddr;
    protected int NCPort;
    protected LinkedList cache;
    protected Alarm[] alms;
    protected int bufPt;
    private static AlarmSender instance = null;
    private Logger logger;
    protected OutputStream os = null;
    protected int interval = CONNECTED;
    protected boolean powerOn = true;
    protected int state = DISCONNECT;
    protected AlarmPool pool = GlobalInstance.getInstance().getAlarmPool();

    private AlarmSender(String addr, int port, int maxIntvl, AlarmPool alarmPool, int bufSize) {
        this.bufPt = DISCONNECT;
        this.logger = null;
        this.NCAddr = addr;
        this.NCPort = port;
        this.maxInterval = maxIntvl * 60;
        this.alms = new Alarm[bufSize];
        this.bufPt = DISCONNECT;
        this.logger = GlobalInstance.getInstance().getLogger();
        this.logger.trace("AlarmSender: init finished.");
    }

    public static synchronized AlarmSender getInstance() {
        if (instance == null) {
            try {
                Configer cf = GlobalInstance.getInstance().getConfiger();
                instance = new AlarmSender(cf.getNetcoolAddr(), cf.getNetcoolPort(), cf.getMaxRetryInterval(), GlobalInstance.getInstance().getAlarmPool(), cf.getSendCacheSize());
            } catch (Exception e) {
                return (AlarmSender) null;
            }
        }
        return instance;
    }

    protected boolean connectNC() {
        try {
            this.socket = new Socket(this.NCAddr, this.NCPort);
            this.os = this.socket.getOutputStream();
            this.logger.info("AlarmSender: Netcool connected.");
            return true;
        } catch (Exception e) {
            this.logger.error("AlarmSender: connect Netcool failed.");
            return false;
        }
    }

    protected void connectRule() {
        if (!this.powerOn) {
            this.interval = CONNECTED;
            this.state = DISCONNECT;
            return;
        }
        while (!connectNC()) {
            this.interval <<= CONNECTED;
            this.interval = this.interval < this.maxInterval ? this.interval : this.maxInterval;
            if (32 == this.interval) {
                if (this.cache != null) {
                    this.pool.pushbackAlarms(this.cache);
                    this.cache.clear();
                }
                GlobalInstance.getInstance().getAlarmPool().setMode(2);
            }
            try {
                Thread.sleep(this.interval * 1000);
            } catch (InterruptedException e) {
            }
            if (!this.powerOn) {
                this.state = DISCONNECT;
                return;
            }
        }
        this.interval = CONNECTED;
        GlobalInstance.getInstance().getAlarmPool().setMode(CONNECTED);
        this.state = CONNECTED;
    }

    public void shutdown(boolean off) {
        this.powerOn = !off;
    }

    protected boolean sendRule(Alarm alm) {
        String str = alm.getContent();
        byte[] buf = str.getBytes();
        if (this.socket.isOutputShutdown()) {
            return false;
        }
        try {
            this.os.write(buf);
            this.os.flush();
            this.logger.debug("AlarmSender.sendRule:has sended ".concat(String.valueOf(String.valueOf(str))));
            return true;
        } catch (IOException e) {
            this.logger.error("AlarmSender.sendRule:failed in send ".concat(String.valueOf(String.valueOf(str))));
            return false;
        }
    }

    @Override // java.lang.Thread, java.lang.Runnable
    public void run() {
        while (this.powerOn) {
            if (this.state == 0) {
                connectRule();
            }
            if (!this.powerOn) {
                break;
            }
            if (this.cache == null || this.cache.isEmpty()) {
                this.cache = this.pool.getAlarms();
            }
            while (true) {
                if (!this.cache.isEmpty() && this.powerOn) {
                    Alarm alm = (Alarm) this.cache.removeFirst();
                    if (!sendRule(alm)) {
                        this.cache.addFirst(alm);
                        for (int i = DISCONNECT; i < this.alms.length; i += CONNECTED) {
                            if (this.alms[i] != null) {
                                this.cache.addFirst(this.alms[i]);
                            }
                            this.alms[i] = null;
                        }
                        this.state = DISCONNECT;
                    } else {
                        this.alms[this.bufPt] = alm;
                        int i2 = this.bufPt + CONNECTED;
                        this.bufPt = i2;
                        this.bufPt = i2 % this.alms.length;
                    }
                }
            }
        }
        for (int i3 = DISCONNECT; i3 < this.alms.length; i3 += CONNECTED) {
            if (this.alms[i3] != null) {
                this.cache.addFirst(this.alms[i3]);
            }
            this.alms[i3] = null;
        }
        if (this.cache != null) {
            this.pool.pushbackAlarms(this.cache);
            this.cache.clear();
        }
        if (this.socket != null) {
            try {
                this.socket.close();
            } catch (IOException e) {
            }
            this.socket = null;
            this.state = DISCONNECT;
        }
        this.logger.info("AlarmSender: Sender alarm thread stopped.");
    }

    public int cacheSize() {
        return this.cache == null ? DISCONNECT : this.cache.size();
    }
}
